# Research on Tabular Deep Learning

**For paper implementations, see the section ["Papers and projects"](#papers-and-projects).**

`rtdl` is a PyTorch-based package providing a user-friendly API for the main models and concepts from our [papers](#papers-and-projects). See the [documentation](https://Yura52.github.io/rtdl).

Press "Watch" to stay up to date with new papers and releases!

Feel free to report [issues](https://github.com/Yura52/rtdl/issues) and post [questions/feedback/ideas](https://github.com/Yura52/rtdl/discussions).

## Papers and projects

| Name                                                          | Location                                                       | Comment        |
| :------------------------------------------------------------ | :------------------------------------------------------------- | :------------- |
| On Embeddings for Numerical Features in Tabular Deep Learning | [link](https://github.com/Yura52/tabular-dl-num-embeddings)    | arXiv 2022     |
| Revisiting Deep Learning Models for Tabular Data              | [link](https://github.com/Yura52/tabular-dl-revisiting-models) | NeurIPS 2021   |
| `rtdl`                                                        | [link](https://github.com/Yura52/rtdl)                         | Python package |
